@@ -14,6 +14,4 @@ def pytest(argv=None):
     except SystemExit:
         pass
     # we need to reset the global py.test.config object
-    py._com.comregistry = py._com.comregistry.__class__([])
-    py.test.config = py.test.config.__class__(
-        pluginmanager=py.test._PluginManager(py._com.comregistry))
+    py.test.config = py.test.config.__class__()
