@@ -1,17 +1,9 @@
 import py
-import sys
-from py.impl.path.svnwc import InfoSvnWCCommand, XMLWCStatus, parse_wcinfotime
-from py.impl.path import svnwc as svncommon
+import os, sys
+from py._path.svnwc import InfoSvnWCCommand, XMLWCStatus, parse_wcinfotime
+from py._path import svnwc as svncommon
 from testing.path.svntestbase import CommonSvnTests
 
-if sys.platform == 'win32':
-    def normpath(p):
-        return p
-else:
-    def normpath(p):
-        p = py.test.importorskip("win32").GetShortPathName(p)
-        return os.path.normpath(os.path.normcase(p))
-
 def test_make_repo(path1, tmpdir):
     repo = tmpdir.join("repo")
     py.process.cmdexec('svnadmin create %s' % repo)
@@ -20,7 +12,7 @@ def test_make_repo(path1, tmpdir):
     repo = py.path.svnurl("file://%s" % repo)
     wc = py.path.svnwc(tmpdir.join("wc"))
     wc.checkout(repo)
-    assert wc.info().rev == 0
+    assert wc.rev == 0
     assert len(wc.listdir()) == 0
     p = wc.join("a_file")
     p.write("test file")
@@ -32,22 +24,10 @@ def test_make_repo(path1, tmpdir):
     assert rev is None
 
 def pytest_funcarg__path1(request):
-    repo, wc = request.getfuncargvalue("repowc1")
+    repo, repourl, wc = request.getfuncargvalue("repowc1")
     return wc
 
 class TestWCSvnCommandPath(CommonSvnTests):
-    def test_move_file(self, path1):  # overrides base class
-        try:
-            super(TestWCSvnCommandPath, self).test_move_file(path1)
-        finally:
-            path1.revert(rec=1)
-
-    def test_move_directory(self, path1): # overrides base class
-        try:
-            super(TestWCSvnCommandPath, self).test_move_directory(path1)
-        finally:
-            path1.revert(rec=1)
-
     def test_status_attributes_simple(self, path1):
         def assert_nochange(p):
             s = p.status()
@@ -181,7 +161,7 @@ class TestWCSvnCommandPath(CommonSvnTests):
         assert [x.basename for x in s.conflict] == ['conflictsamplefile']
 
     def test_status_external(self, path1, repowc2):
-        otherrepo, otherwc = repowc2
+        otherrepo, otherrepourl, otherwc = repowc2
         d = path1.ensure('sampledir', dir=1)
         try:
             d.remove()
@@ -366,7 +346,8 @@ class TestWCSvnCommandPath(CommonSvnTests):
         try:
             locked = root.status().locked
             assert len(locked) == 1
-            assert normpath(str(locked[0])) == normpath(str(somefile))
+            assert locked[0].basename == somefile.basename
+            assert locked[0].dirpath().basename == somefile.dirpath().basename
             #assert somefile.locked()
             py.test.raises(Exception, 'somefile.lock()')
         finally:
