@@ -3,19 +3,15 @@ terminal reporting of the full testing process.
 """
 import py
 import sys
-try:
-    import execnet
-except ImportError:
-    execnet = None
 
 # ===============================================================================
 # plugin tests 
 #
 # ===============================================================================
 
-from py.plugin.pytest_terminal import TerminalReporter, \
+from py._plugin.pytest_terminal import TerminalReporter, \
     CollectonlyReporter,  repr_pythonversion, getreportopt
-from py.plugin import pytest_runner as runner 
+from py._plugin import pytest_runner as runner 
 
 def basic_run_report(item):
     return runner.call_and_report(item, "call", log=False)
@@ -37,20 +33,16 @@ class Option:
 
 def pytest_generate_tests(metafunc):
     if "option" in metafunc.funcargnames:
-        metafunc.addcall(
-            id="default", 
-            funcargs={'option': Option(verbose=False)}
-        )
-        metafunc.addcall(
-            id="verbose", 
-            funcargs={'option': Option(verbose=True)}
-        )
-        nodist = getattr(metafunc.function, 'nodist', False)
-        if execnet and not nodist:
-            metafunc.addcall(
-                id="verbose-dist", 
-                funcargs={'option': Option(dist='each', verbose=True)}
-            )
+        metafunc.addcall(id="default", param=Option(verbose=False))
+        metafunc.addcall(id="verbose", param=Option(verbose=True))
+        if not getattr(metafunc.function, 'nodist', False):
+            metafunc.addcall(id="verbose-dist", 
+                             param=Option(dist='each', verbose=True))
+
+def pytest_funcarg__option(request):
+    if request.param.dist:
+        request.config.pluginmanager.skipifmissing("xdist")
+    return request.param
 
 class TestTerminal:
     def test_pass_skip_fail(self, testdir, option):
@@ -108,40 +100,6 @@ class TestTerminal:
             "INTERNALERROR> *raise ValueError*"
         ])
 
-    def test_gwmanage_events(self, testdir, linecomp):
-        execnet = py.test.importorskip("execnet")
-        modcol = testdir.getmodulecol("""
-            def test_one():
-                pass
-        """, configargs=("-v",))
-
-        rep = TerminalReporter(modcol.config, file=linecomp.stringio)
-        class gw1:
-            id = "X1"
-            spec = execnet.XSpec("popen")
-        class gw2:
-            id = "X2"
-            spec = execnet.XSpec("popen")
-        class rinfo:
-            version_info = (2, 5, 1, 'final', 0)
-            executable = "hello"
-            platform = "xyz"
-            cwd = "qwe"
-        
-        rep.pytest_gwmanage_newgateway(gw1, rinfo)
-        linecomp.assert_contains_lines([
-            "*X1*popen*xyz*2.5*"
-        ])
-
-        rep.pytest_gwmanage_rsyncstart(source="hello", gateways=[gw1, gw2])
-        linecomp.assert_contains_lines([
-            "rsyncstart: hello -> [X1], [X2]"
-        ])
-        rep.pytest_gwmanage_rsyncfinish(source="hello", gateways=[gw1, gw2])
-        linecomp.assert_contains_lines([
-            "rsyncfinish: hello -> [X1], [X2]"
-        ])
-
     def test_writeline(self, testdir, linecomp):
         modcol = testdir.getmodulecol("def test_one(): pass")
         stringio = py.io.TextIO()
@@ -195,6 +153,26 @@ class TestTerminal:
                 assert '--calling--' not in s
                 assert 'IndexError' not in s
 
+    def test_tb_crashline(self, testdir, option):
+        p = testdir.makepyfile("""
+            import py
+            def g():
+                raise IndexError
+            def test_func1():
+                print (6*7)
+                g()  # --calling--
+            def test_func2():
+                assert 0, "hello"
+        """)
+        result = testdir.runpytest("--tb=line")
+        bn = p.basename
+        result.stdout.fnmatch_lines([
+            "*%s:3: IndexError*" % bn,
+            "*%s:8: AssertionError: hello*" % bn,
+        ])
+        s = result.stdout.str()
+        assert "def test_func2" not in s
+
     def test_show_path_before_running_test(self, testdir, linecomp):
         item = testdir.getitem("def test_func(): pass")
         tr = TerminalReporter(item.config, file=linecomp.stringio)
@@ -258,12 +236,19 @@ class TestTerminal:
         ])
 
     def test_keyboard_interrupt_dist(self, testdir, option):
+        # xxx could be refined to check for return code 
         p = testdir.makepyfile("""
-            raise KeyboardInterrupt
+            def test_sleep():
+                import time
+                time.sleep(10)
         """)
-        result = testdir.runpytest(*option._getcmdargs())
-        assert result.ret == 2
-        result.stdout.fnmatch_lines(['*KEYBOARD INTERRUPT*'])
+        child = testdir.spawn_pytest(" ".join(option._getcmdargs()))
+        child.expect(".*test session starts.*")
+        child.kill(2) # keyboard interrupt
+        child.expect(".*KeyboardInterrupt.*")
+        #child.expect(".*seconds.*")
+        child.close()
+        #assert ret == 2 
 
     @py.test.mark.nodist
     def test_keyboard_interrupt(self, testdir, option):
@@ -289,6 +274,22 @@ class TestTerminal:
             ])
         result.stdout.fnmatch_lines(['*KEYBOARD INTERRUPT*'])
 
+    def test_pytest_report_header(self, testdir):
+        testdir.makeconftest("""
+            def pytest_report_header(config):
+                return "hello: info" 
+        """)
+        testdir.mkdir("a").join("conftest.py").write("""if 1:
+            def pytest_report_header(config):
+                return ["line1", "line2"]
+        """)
+        result = testdir.runpytest("a")
+        result.stdout.fnmatch_lines([
+            "*hello: info*",
+            "line1",
+            "line2",
+        ])
+
 
 class TestCollectonly:
     def test_collectonly_basic(self, testdir, linecomp):
@@ -529,7 +530,7 @@ class TestTerminalFunctional:
             "y* = 'xxxxxx*"
         ])
 
-    def test_verbose_reporting(self, testdir):
+    def test_verbose_reporting(self, testdir, pytestconfig):
         p1 = testdir.makepyfile("""
             import py
             def test_fail():
@@ -552,12 +553,12 @@ class TestTerminalFunctional:
             "*test_verbose_reporting.py:10: test_gen*FAIL*",
         ])
         assert result.ret == 1
-        if execnet:
-            result = testdir.runpytest(p1, '-v', '-n 1')
-            result.stdout.fnmatch_lines([
-                "*FAIL*test_verbose_reporting.py:2: test_fail*", 
-            ])
-            assert result.ret == 1
+        pytestconfig.pluginmanager.skipifmissing("xdist")
+        result = testdir.runpytest(p1, '-v', '-n 1')
+        result.stdout.fnmatch_lines([
+            "*FAIL*test_verbose_reporting.py:2: test_fail*", 
+        ])
+        assert result.ret == 1
 
 
 def test_getreportopt():
@@ -580,9 +581,20 @@ def test_terminalreporter_reportopt_conftestsetting(testdir):
     assert result.stdout.fnmatch_lines([
         "*1 passed*"
     ])
-    def test_trace_reporting(self, testdir):
-        result = testdir.runpytest("--trace")
-        assert result.stdout.fnmatch_lines([
-            "*active plugins*"
-        ])
-        assert result.ret == 0
+
+def test_trace_reporting(testdir):
+    result = testdir.runpytest("--traceconfig")
+    assert result.stdout.fnmatch_lines([
+        "*active plugins*"
+    ])
+    assert result.ret == 0
+
+@py.test.mark.nodist
+def test_show_funcarg(testdir, option):
+    args = option._getcmdargs() + ["--funcargs"]
+    result = testdir.runpytest(*args)
+    assert result.stdout.fnmatch_lines([
+            "*tmpdir*",
+            "*temporary directory*",
+        ]
+    )
