@@ -1,7 +1,7 @@
-from py.plugin.pytest_tmpdir import pytest_funcarg__tmpdir
+from py._plugin.pytest_tmpdir import pytest_funcarg__tmpdir
 
 def test_funcarg(testdir):
-    from py.impl.test.funcargs import FuncargRequest
+    from py._test.funcargs import FuncargRequest
     item = testdir.getitem("def test_func(tmpdir): pass")
     p = pytest_funcarg__tmpdir(FuncargRequest(item))
     assert p.check()
