@@ -1,10 +1,9 @@
 
 import py, sys
 
-def test_kill():
+def test_kill(tmpdir):
     subprocess = py.test.importorskip("subprocess")
-    tmp = py.test.ensuretemp("test_kill")
-    t = tmp.join("t.py")
+    t = tmpdir.join("t.py")
     t.write("import time ; time.sleep(100)")
     proc = py.std.subprocess.Popen([sys.executable, str(t)])
     assert proc.poll() is None # no return value yet
